# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.4] - 2026-01-24

### Changed

- Update config, core, deps

## [0.2.3] - 2026-01-22

### Changed

- Raindropio-mcp (quality: 77/100) - 2026-01-22 17:00:08
- Update config, core, docs

## [0.2.2] - 2026-01-05

### Changed

- Update config, core

### Fixed

- Correct MCP server default port to 3034 and update tests

## [0.2.1] - 2026-01-05

### Changed

- Update config, core, deps

## [0.2.0] - 2026-01-04

### Changed

- Migrate raindropio-mcp to mcp-common v0.4.4
- Update config, core, deps, tests

## [0.1.3] - 2025-12-20

### Changed

- Update config, core, deps, docs, tests

### Fixed

- test: Update 181 files
